@@ -11,7 +11,7 @@ import aiohttp_socks
 import tibiapy
 from tibiapy import abc, AuctionDetails, AuctionFilters, CharacterBazaar
 from tibiapy.character import Character
-from tibiapy.creature import BoostedCreature
+from tibiapy.creature import CreaturesSection, Creature, CreatureDetail
 from tibiapy.enums import Category, HouseOrder, HouseStatus, HouseType, NewsCategory, NewsType, VocationFilter
 from tibiapy.errors import Forbidden, NetworkError, SiteMaintenanceError
 from tibiapy.event import EventSchedule
@@ -37,6 +37,7 @@ T = typing.TypeVar('T')
 
 log = logging.getLogger("tibiapy")
 
+
 class TibiaResponse(typing.Generic[T], abc.Serializable):
     """Represents a response from Tibia.com
 
@@ -183,13 +184,14 @@ class Client:
         await self._session_ready.wait()
         try:
             init_time = time.perf_counter()
-            log.info(f"%s | %s | Fetching...", url, method)
             async with self.session.request(method, url, data=data, headers=headers) as resp:
-                log.info(f"%s | %s | %s %s", url, method, resp.status, resp.reason)
+                diff_time = time.perf_counter()-init_time
                 if "maintenance.tibia.com" in str(resp.url):
+                    log.info(f"%s | %s | %s %s | maintenance.tibia.com", url, resp.method, resp.status, resp.reason)
                     raise SiteMaintenanceError("Tibia.com is down for maintenance.")
+                log.info(f"%s | %s | %s %s | %dms", url, resp.method, resp.status, resp.reason, int(diff_time*1000))
                 self._handle_status(resp.status)
-                response = RawResponse(resp, time.perf_counter()-init_time)
+                response = RawResponse(resp, diff_time)
                 response.content = await resp.text()
                 return response
         except aiohttp.ClientError as e:
@@ -226,7 +228,7 @@ class Client:
         ValueError
             If the page number is not 1 or greater.
         """
-        if not page:
+        if page <= 0:
             raise ValueError('page must be 1 or greater.')
         response = await self._request("GET", CharacterBazaar.get_current_auctions_url(page, filters))
         start_time = time.perf_counter()
@@ -259,7 +261,7 @@ class Client:
         ValueError
             If the page number is not 1 or greater.
         """
-        if not page:
+        if page <= 0:
             raise ValueError('page must be 1 or greater.')
         response = await self._request("GET", CharacterBazaar.get_auctions_history_url(page))
         start_time = time.perf_counter()
@@ -301,7 +303,11 @@ class Client:
             This usually means that Tibia.com is rate-limiting the client because of too many requests.
         NetworkError
             If there's any connection errors during the request.
+        ValueError
+            If the auction id is not 1 or greater.
         """
+        if auction_id <= 0:
+            raise ValueError('auction_id must be 1 or greater.')
         response = await self._request("GET", AuctionDetails.get_url(auction_id))
         start_time = time.perf_counter()
         auction = AuctionDetails.from_content(response.content, auction_id, skip_details)
@@ -319,7 +325,7 @@ class Client:
         return TibiaResponse(response, auction, parsing_time)
 
     async def _fetch_all_pages(self, auction_id, paginator, item_type):
-        """Fetches all the pages of a auction paginator.
+        """Fetches all the pages of an auction paginator.
 
         Parameters
         ----------
@@ -335,7 +341,7 @@ class Client:
         current_page = 2
         while current_page <= paginator.total_pages:
             content = await self._fetch_ajax_page(auction_id, item_type, current_page)
-            entries = AuctionDetails.parse_page_items(content, paginator.entry_class)
+            entries = AuctionDetails._parse_page_items(content, paginator.entry_class)
             paginator.entries.extend(entries)
             current_page += 1
         paginator.fully_fetched = True
@@ -409,7 +415,7 @@ class Client:
         return TibiaResponse(response, cm_post_archive, parsing_time)
 
     async def fetch_event_schedule(self, month=None, year=None):
-        """Fetches the event calendar.
+        """Fetches the event calendar. By default, it gets the events for the current month.
 
         .. versionadded:: 3.0.0
 
@@ -432,6 +438,8 @@ class Client:
             This usually means that Tibia.com is rate-limiting the client because of too many requests.
         NetworkError
             If there's any connection errors during the request.
+        ValueError
+            If only one of year or month are defined.
         """
         if (year is None and month is not None) or (year is not None and month is None):
             raise ValueError("both year and month must be defined or neither must be defined.")
@@ -666,10 +674,12 @@ class Client:
         """Fetches today's boosted creature.
 
         .. versionadded:: 2.1.0
+        .. versionchanged:: 4.0.0
+            The return type of the data returned was changed to :class:`Creature`, previous type was removed.
 
         Returns
         -------
-        :class:`TibiaResponse` of :class:`BoostedCreature`
+        :class:`TibiaResponse` of :class:`Creature`
             The boosted creature of the day.
 
         Raises
@@ -682,7 +692,60 @@ class Client:
         """
         response = await self._request("GET", News.get_list_url())
         start_time = time.perf_counter()
-        boosted_creature = BoostedCreature.from_content(response.content)
+        boosted_creature = CreaturesSection.from_boosted_creature_header(response.content)
+        parsing_time = time.perf_counter() - start_time
+        return TibiaResponse(response, boosted_creature, parsing_time)
+
+    async def fetch_library_creatures(self):
+        """Fetches the creatures from the library section.
+
+        .. versionadded:: 4.0.0
+
+        Returns
+        -------
+        :class:`TibiaResponse` of :class:`CreaturesSection`
+            The creature's section in Tibia.com
+
+        Raises
+        ------
+        Forbidden
+            If a 403 Forbidden error was returned.
+            This usually means that Tibia.com is rate-limiting the client because of too many requests.
+        NetworkError
+            If there's any connection errors during the request.
+        """
+        response = await self._request("GET", CreaturesSection.get_url())
+        start_time = time.perf_counter()
+        boosted_creature = CreaturesSection.from_content(response.content)
+        parsing_time = time.perf_counter() - start_time
+        return TibiaResponse(response, boosted_creature, parsing_time)
+
+    async def fetch_creature(self, race):
+        """Fetches a creature's information from the Tibia.com library.
+
+        .. versionadded:: 4.0.0
+
+        Parameters
+        ----------
+        race: :class:`str`
+            The internal name of the race.
+
+        Returns
+        -------
+        :class:`TibiaResponse` of :class:`CreatureDetail`
+            The creature's section in Tibia.com
+
+        Raises
+        ------
+        Forbidden
+            If a 403 Forbidden error was returned.
+            This usually means that Tibia.com is rate-limiting the client because of too many requests.
+        NetworkError
+            If there's any connection errors during the request.
+        """
+        response = await self._request("GET", CreatureDetail.get_url(race))
+        start_time = time.perf_counter()
+        boosted_creature = CreatureDetail.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
         return TibiaResponse(response, boosted_creature, parsing_time)
 
@@ -697,7 +760,7 @@ class Client:
         Returns
         -------
         :class:`TibiaResponse` of :class:`Character`
-            A response containig the character, if found.
+            A response containing the character, if found.
 
         Raises
         ------
@@ -1041,7 +1104,7 @@ class Client:
         if NewsType.NEWS_TICKER in types:
             data["filter_ticker"] = "ticker"
 
-        response = await self._request("post", News.get_list_url(), data)
+        response = await self._request("POST", News.get_list_url(), data)
         start_time = time.perf_counter()
         news = ListedNews.list_from_content(response.content)
         parsing_time = time.perf_counter() - start_time
